==> ejc-hrmanage-api-3.0.0-20251204.101454-199-sources.jar: com/ejianc/business/hr/hystrix/BaseUserHystrix.java <==
package com.ejianc.business.hr.hystrix;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.hr.api.IBaseUserApi;
import com.ejianc.business.hr.vo.ResidencyUserVO;

import com.ejianc.business.hr.vo.salarySystem.SalaryAttendanceDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryJobDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryTransferDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryUserDataVO;
import com.ejianc.business.hr.vo.UserDataVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * 项目立项rpc服务
 */
@Component
public class BaseUserHystrix implements IBaseUserApi {

    @Override
    public CommonResponse<IPage<ResidencyUserVO>> queryResidencyUser(QueryParam param) {
        return null;
    }

    @Override
    public CommonResponse<List<UserDataVO>> queryAllUserDataApi(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryUserDataVO>> queryAllUserSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryJobDataVO>> queryAllJobSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryAttendanceDataVO>> queryAllAttendanceSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryTransferDataVO>> queryAllTransferSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }
}

==> ejc-hrmanage-api-3.0.0-20251210.072145-201-sources.jar: com/ejianc/business/hr/hystrix/BaseUserHystrix.java <==
package com.ejianc.business.hr.hystrix;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.hr.api.IBaseUserApi;
import com.ejianc.business.hr.vo.ResidencyUserVO;

import com.ejianc.business.hr.vo.hrm.UserJobVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryAttendanceDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryJobDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryTransferDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryUserDataVO;
import com.ejianc.business.hr.vo.UserDataVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;


/**
 * 项目立项rpc服务
 */
@Component
public class BaseUserHystrix implements IBaseUserApi {

    @Override
    public CommonResponse<IPage<ResidencyUserVO>> queryResidencyUser(QueryParam param) {
        return null;
    }

    @Override
    public CommonResponse<List<UserDataVO>> queryAllUserDataApi(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryUserDataVO>> queryAllUserSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryJobDataVO>> queryAllJobSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryAttendanceDataVO>> queryAllAttendanceSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<SalaryTransferDataVO>> queryAllTransferSalary(QueryParam param) {
        return CommonResponse.error("查询失败！！");
    }

    @Override
    public CommonResponse<List<UserJobVO>> refPartTimeUserList(String userCode, String jobState) {
        return CommonResponse.error("查询失败！！");
    }
}
